import React, { InputHTMLAttributes, forwardRef, useState, ReactNode } from 'react';
import { FaEye, FaEyeSlash, FaExclamationCircle } from 'react-icons/fa';
import styles from '@/styles/common/Input.module.scss';

export interface InputProps extends InputHTMLAttributes<HTMLInputElement> {
  label?: string;
  error?: string;
  helpText?: string;
  leftIcon?: ReactNode;
  rightIcon?: ReactNode;
  fullWidth?: boolean;
  showPasswordToggle?: boolean;
  testId?: string;
  wrapperClassName?: string;
  labelClassName?: string;
}

const Input = forwardRef<HTMLInputElement, InputProps>(({
  label,
  error,
  helpText,
  leftIcon,
  rightIcon,
  fullWidth = false,
  disabled = false,
  required = false,
  type = 'text',
  className = '',
  showPasswordToggle = false,
  testId,
  wrapperClassName,
  labelClassName,
  ...props
}, ref) => {
  const [showPassword, setShowPassword] = useState(false);
  
  const togglePasswordVisibility = () => {
    setShowPassword(!showPassword);
  };
  
  // Determine final input type
  const inputType = type === 'password' && showPassword ? 'text' : type;
  
  // Generate unique IDs for accessibility
  const inputId = props.id || `input-${Math.random().toString(36).slice(2, 11)}`;
  const errorId = error ? `${inputId}-error` : undefined;
  const helpTextId = helpText ? `${inputId}-help` : undefined;
  
  return (
    <div 
      className={`
        ${styles.inputWrapper} 
        ${fullWidth ? styles.fullWidth : ''} 
        ${disabled ? styles.disabled : ''}
        ${error ? styles.hasError : ''}
        ${wrapperClassName || ''}
      `}
    >
      {label && (
        <label 
          htmlFor={inputId} 
          className={`${styles.label} ${labelClassName || ''}`}
        >
          {label}
          {required && <span className={styles.required}>*</span>}
        </label>
      )}
      
      <div className={styles.inputContainer}>
        {leftIcon && (
          <span className={styles.leftIcon} aria-hidden="true">
            {leftIcon}
          </span>
        )}
        
        <input
          ref={ref}
          id={inputId}
          type={inputType}
          className={`
            ${styles.input}
            ${leftIcon ? styles.hasLeftIcon : ''}
            ${rightIcon || (type === 'password' && showPasswordToggle) ? styles.hasRightIcon : ''}
            ${className}
          `}
          disabled={disabled}
          aria-invalid={!!error}
          aria-describedby={
            [errorId, helpTextId].filter(Boolean).join(' ') || undefined
          }
          data-testid={testId}
          {...props}
        />
        
        {type === 'password' && showPasswordToggle && (
          <button
            type="button"
            className={styles.passwordToggle}
            onClick={togglePasswordVisibility}
            aria-label={showPassword ? 'Hide password' : 'Show password'}
            tabIndex={-1}
          >
            {showPassword ? <FaEyeSlash /> : <FaEye />}
          </button>
        )}
        
        {rightIcon && type !== 'password' && (
          <span className={styles.rightIcon} aria-hidden="true">
            {rightIcon}
          </span>
        )}
      </div>
      
      {(error || helpText) && (
        <div className={styles.bottomText}>
          {error && (
            <span id={errorId} className={styles.errorText}>
              <FaExclamationCircle />
              {error}
            </span>
          )}
          {!error && helpText && (
            <span id={helpTextId} className={styles.helpText}>
              {helpText}
            </span>
          )}
        </div>
      )}
    </div>
  );
});

Input.displayName = 'Input';

export default Input;